==> jc-1.4.0.tar.gz: java/awt/MenuBar__24AccessibleAWTMenuBar.h <==
// public class java.awt.MenuBar$AccessibleAWTMenuBar

// class file dependencies
// @dep_class 89b98695c3bf8527 java_awt_MenuBar__24AccessibleAWTMenuBar
// @dep_class 1a6b784cf6e839c6 java_awt_MenuComponent__24AccessibleAWTMenuComponent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_MenuComponent__24AccessibleAWTMenuComponent

#include "java/awt/MenuComponent__24AccessibleAWTMenuComponent.h"

#ifndef _JC_java_awt_MenuBar__24AccessibleAWTMenuBar_H_
#define _JC_java_awt_MenuBar__24AccessibleAWTMenuBar_H_

// Forward structure declarations
struct _jc_java_awt_MenuBar$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_refs	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_refs;
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_nonrefs	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_nonrefs;
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$refs	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$refs;
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$nonrefs	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$nonrefs;
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object;

typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$fields_struct	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$fields_struct;
typedef const struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vmethods	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vmethods;
typedef const struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtable	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtable;
typedef const struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype;

// Class fields structure
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$fields_struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$class_fields;

// Constructors
extern void _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$method$_init$4781d7bab77689ff(_jc_env *, struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object *, struct _jc_java_awt_MenuBar$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object *);
};

// Vtable
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$vmethods	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vmethods	java_awt_MenuBar__24AccessibleAWTMenuBar;
};

// Vtype
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype {
	_jc_type			type;
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_refs {
	struct _jc_java_awt_MenuBar$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$refs {
    _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_refs	java_awt_MenuBar__24AccessibleAWTMenuBar;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_refs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_nonrefs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_nonrefs	java_awt_MenuBar__24AccessibleAWTMenuBar;
};

// Object instance structure
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object {
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype	*vtype;
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_MenuBar__24AccessibleAWTMenuBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$class_object;

#endif	/* _JC_java_awt_MenuBar__24AccessibleAWTMenuBar_H_ */

==> jc-1.4.6.tar.gz: java/awt/MenuBar__24AccessibleAWTMenuBar.h <==
// public class java.awt.MenuBar$AccessibleAWTMenuBar

// class file dependencies
// @dep_class 89b98695c3bf8527 java_awt_MenuBar__24AccessibleAWTMenuBar
// @dep_class 8b7c1e30849dcda2 java_awt_MenuComponent__24AccessibleAWTMenuComponent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_MenuComponent__24AccessibleAWTMenuComponent

#include "java/awt/MenuComponent__24AccessibleAWTMenuComponent.h"

#ifndef _JC_java_awt_MenuBar__24AccessibleAWTMenuBar_H_
#define _JC_java_awt_MenuBar__24AccessibleAWTMenuBar_H_

// Forward structure declarations
struct _jc_java_awt_MenuBar$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_refs	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_refs;
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_nonrefs	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_nonrefs;
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$refs	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$refs;
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$nonrefs	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$nonrefs;
typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object;

typedef struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$fields_struct	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$fields_struct;
typedef const struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vmethods	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vmethods;
typedef const struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtable	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtable;
typedef const struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype;

// Class fields structure
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$fields_struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$class_fields;

// Constructors
extern void _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$method$_init$4781d7bab77689ff(_jc_env *, struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object *, struct _jc_java_awt_MenuBar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$vmethods	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vmethods	java_awt_MenuBar__24AccessibleAWTMenuBar;
};

// Vtype
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype {
	_jc_type			type;
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_refs {
	struct _jc_java_awt_MenuBar$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$refs {
    _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_refs	java_awt_MenuBar__24AccessibleAWTMenuBar;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_refs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_nonrefs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$sub_nonrefs	java_awt_MenuBar__24AccessibleAWTMenuBar;
};

// Object instance structure
struct _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$object {
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype	*vtype;
	_jc_java_awt_MenuBar__24AccessibleAWTMenuBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$vtype _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_MenuBar__24AccessibleAWTMenuBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_MenuBar__24AccessibleAWTMenuBar$class_object;

#endif	/* _JC_java_awt_MenuBar__24AccessibleAWTMenuBar_H_ */
